==> deepin-shell-debug-2.0.23-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-shell/dde-shell/panels/dock/taskmanager/dock-taskmanager_autogen/EWIEGA46WW/qrc_x11preview.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // close.dci
  0x0,0x0,0x2,0xd3,
  0x44,
  0x43,0x49,0x0,0x1,0x1,0x0,0x0,0x2,0x31,0x36,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x83,0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x2,
  0x6e,0x6f,0x72,0x6d,0x61,0x6c,0x2e,0x64,0x61,0x72,0x6b,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xad,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x2,0x33,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3,
  0x31,0x2e,0x30,0x2e,0x77,0x65,0x62,0x70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1d,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x2e,0x2e,0x2f,0x2e,0x2e,0x2f,0x6e,0x6f,0x72,
  0x6d,0x61,0x6c,0x2e,0x6c,0x69,0x67,0x68,0x74,0x2f,0x33,0x2f,0x31,0x2e,0x30,0x2e,
  0x77,0x65,0x62,0x70,0x2,0x6e,0x6f,0x72,0x6d,0x61,0x6c,0x2e,0x6c,0x69,0x67,0x68,
  0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x46,0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x2,0x33,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfe,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x1,0x31,0x2e,0x30,0x2e,0x77,0x65,0x62,0x70,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0xb6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x52,0x49,0x46,0x46,
  0xae,0x0,0x0,0x0,0x57,0x45,0x42,0x50,0x56,0x50,0x38,0x4c,0xa2,0x0,0x0,0x0,
  0x2f,0x2f,0xc0,0xb,0x10,0x57,0x10,0x11,0x64,0x2,0x96,0x51,0xbb,0xbc,0x9a,0xa8,
  0x20,0x91,0x90,0x29,0x39,0xcc,0x70,0x1a,0xdb,0xb6,0xab,0xdc,0x4f,0xe8,0x20,0xd9,
  0x1c,0x5a,0xc0,0xe2,0x70,0xd4,0x41,0x7,0x20,0x9f,0xe3,0x6b,0x52,0x9,0x6f,0x6e,
  0x9d,0xef,0x4,0xf7,0x6d,0x44,0xff,0xd1,0xb6,0x6d,0x9b,0x18,0x5,0xd1,0x2d,0x49,
  0x7b,0x45,0xc,0x74,0x76,0x41,0x72,0xa1,0xe7,0xf6,0x1a,0x5,0x64,0xf5,0x9f,0xb2,
  0x7a,0xe7,0x29,0x20,0x25,0xcf,0xac,0x4a,0xf6,0x23,0xb0,0xe6,0x92,0xd5,0xaa,0x22,
  0x25,0x9f,0x5d,0x68,0x50,0xd,0x2a,0x41,0x35,0xa8,0x1,0xaa,0x41,0x35,0xa0,0x1,
  0x68,0xd0,0x6a,0xd5,0x29,0xdc,0x4b,0x3f,0xf2,0xbc,0x57,0x83,0x76,0xc5,0xc5,0xa0,
  0x5d,0xf1,0xca,0xa1,0x5d,0xb1,0x43,0xbb,0xe2,0x16,0x43,0x44,0x8b,0x68,0x9,0x5a,
  0xcd,0x3b,0x97,0xac,0xb5,0x2b,0xfd,0xcf,0x8f,0xce,0xfc,0xcf,0x31,0x13,0xff,0x7f,
  0x90,0x13,
  
};

static const unsigned char qt_resource_name[] = {
  // dsg
  0x0,0x3,
  0x0,0x0,0x6b,0x97,
  0x0,0x64,
  0x0,0x73,0x0,0x67,
    // built-in-icons
  0x0,0xe,
  0x9,0x39,0x9b,0xb3,
  0x0,0x62,
  0x0,0x75,0x0,0x69,0x0,0x6c,0x0,0x74,0x0,0x2d,0x0,0x69,0x0,0x6e,0x0,0x2d,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // close.dci
  0x0,0x9,
  0x6,0x98,0x9e,0xf9,
  0x0,0x63,
  0x0,0x6c,0x0,0x6f,0x0,0x73,0x0,0x65,0x0,0x2e,0x0,0x64,0x0,0x63,0x0,0x69,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0xb2,0xce,0x8e,0x80,
  // :/dsg
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0xb2,0xce,0x8e,0x80,
  // :/dsg/built-in-icons
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9b,0xb2,0xce,0x8e,0x80,
  // :/dsg/built-in-icons/close.dci
  0x0,0x0,0x0,0x2e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xb2,0xce,0x8e,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_x11preview)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_x11preview)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_x11preview)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_x11preview)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_x11preview)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_x11preview)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif

==> deepin-shell-debug-2.0.24-1-x86_64.pkg.tar.zst: usr/src/debug/deepin-shell/dde-shell/panels/dock/taskmanager/dock-taskmanager_autogen/EWIEGA46WW/qrc_x11preview.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.10.1
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // close.dci
  0x0,0x0,0x2,0xd3,
  0x44,
  0x43,0x49,0x0,0x1,0x1,0x0,0x0,0x2,0x31,0x36,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x83,0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x2,
  0x6e,0x6f,0x72,0x6d,0x61,0x6c,0x2e,0x64,0x61,0x72,0x6b,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xad,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x2,0x33,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x3,
  0x31,0x2e,0x30,0x2e,0x77,0x65,0x62,0x70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1d,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x2e,0x2e,0x2f,0x2e,0x2e,0x2f,0x6e,0x6f,0x72,
  0x6d,0x61,0x6c,0x2e,0x6c,0x69,0x67,0x68,0x74,0x2f,0x33,0x2f,0x31,0x2e,0x30,0x2e,
  0x77,0x65,0x62,0x70,0x2,0x6e,0x6f,0x72,0x6d,0x61,0x6c,0x2e,0x6c,0x69,0x67,0x68,
  0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x46,0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x2,0x33,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0xfe,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x1,0x31,0x2e,0x30,0x2e,0x77,0x65,0x62,0x70,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  0x0,0x0,0x0,0x0,0xb6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x52,0x49,0x46,0x46,
  0xae,0x0,0x0,0x0,0x57,0x45,0x42,0x50,0x56,0x50,0x38,0x4c,0xa2,0x0,0x0,0x0,
  0x2f,0x2f,0xc0,0xb,0x10,0x57,0x10,0x11,0x64,0x2,0x96,0x51,0xbb,0xbc,0x9a,0xa8,
  0x20,0x91,0x90,0x29,0x39,0xcc,0x70,0x1a,0xdb,0xb6,0xab,0xdc,0x4f,0xe8,0x20,0xd9,
  0x1c,0x5a,0xc0,0xe2,0x70,0xd4,0x41,0x7,0x20,0x9f,0xe3,0x6b,0x52,0x9,0x6f,0x6e,
  0x9d,0xef,0x4,0xf7,0x6d,0x44,0xff,0xd1,0xb6,0x6d,0x9b,0x18,0x5,0xd1,0x2d,0x49,
  0x7b,0x45,0xc,0x74,0x76,0x41,0x72,0xa1,0xe7,0xf6,0x1a,0x5,0x64,0xf5,0x9f,0xb2,
  0x7a,0xe7,0x29,0x20,0x25,0xcf,0xac,0x4a,0xf6,0x23,0xb0,0xe6,0x92,0xd5,0xaa,0x22,
  0x25,0x9f,0x5d,0x68,0x50,0xd,0x2a,0x41,0x35,0xa8,0x1,0xaa,0x41,0x35,0xa0,0x1,
  0x68,0xd0,0x6a,0xd5,0x29,0xdc,0x4b,0x3f,0xf2,0xbc,0x57,0x83,0x76,0xc5,0xc5,0xa0,
  0x5d,0xf1,0xca,0xa1,0x5d,0xb1,0x43,0xbb,0xe2,0x16,0x43,0x44,0x8b,0x68,0x9,0x5a,
  0xcd,0x3b,0x97,0xac,0xb5,0x2b,0xfd,0xcf,0x8f,0xce,0xfc,0xcf,0x31,0x13,0xff,0x7f,
  0x90,0x13,
  
};

static const unsigned char qt_resource_name[] = {
  // dsg
  0x0,0x3,
  0x0,0x0,0x6b,0x97,
  0x0,0x64,
  0x0,0x73,0x0,0x67,
    // built-in-icons
  0x0,0xe,
  0x9,0x39,0x9b,0xb3,
  0x0,0x62,
  0x0,0x75,0x0,0x69,0x0,0x6c,0x0,0x74,0x0,0x2d,0x0,0x69,0x0,0x6e,0x0,0x2d,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // close.dci
  0x0,0x9,
  0x6,0x98,0x9e,0xf9,
  0x0,0x63,
  0x0,0x6c,0x0,0x6f,0x0,0x73,0x0,0x65,0x0,0x2e,0x0,0x64,0x0,0x63,0x0,0x69,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9b,0xc7,0x0,0x1c,0xc0,
  // :/dsg
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9b,0xc7,0x0,0x1c,0xc0,
  // :/dsg/built-in-icons
  0x0,0x0,0x0,0xc,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9b,0xc7,0x0,0x1c,0xc0,
  // :/dsg/built-in-icons/close.dci
  0x0,0x0,0x0,0x2e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9b,0xc7,0x0,0x1c,0xc0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_x11preview)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_x11preview)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_x11preview)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_x11preview)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_x11preview)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_x11preview)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
